summaryrefslogtreecommitdiff
path: root/drivers/staging/most/hdm-dim2/dim2_hdm.c
diff options
context:
space:
mode:
authorChaehyun Lim <chaehyun.lim@gmail.com>2015-11-02 16:59:04 +0300
committerGreg Kroah-Hartman <gregkh@linuxfoundation.org>2015-11-16 07:02:47 +0300
commit58889788fc806e8b63e7f159db659937decf61e8 (patch)
treeac639ec15b9ab5cc5ed5b1c88b40f468917a753f /drivers/staging/most/hdm-dim2/dim2_hdm.c
parent1efc4564624070561c1a562f2001ca357895cc99 (diff)
downloadlinux-58889788fc806e8b63e7f159db659937decf61e8.tar.xz
staging: most: rename DIMCB_IoRead to dimcb_io_read
This patch renames DIMCB_IoRead to dimcb_io_read to avoid camelcase found by checkpatch. CHECK: Avoid CamelCase: <DIMCB_IoRead> FILE: drivers/staging/most/hdm-dim2/dim2_hal.c:157: Signed-off-by: Chaehyun Lim <chaehyun.lim@gmail.com> Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Diffstat (limited to 'drivers/staging/most/hdm-dim2/dim2_hdm.c')
-rw-r--r--drivers/staging/most/hdm-dim2/dim2_hdm.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/staging/most/hdm-dim2/dim2_hdm.c b/drivers/staging/most/hdm-dim2/dim2_hdm.c
index d8a0790979bf..1b792f1861c2 100644
--- a/drivers/staging/most/hdm-dim2/dim2_hdm.c
+++ b/drivers/staging/most/hdm-dim2/dim2_hdm.c
@@ -135,10 +135,10 @@ bool dim2_sysfs_get_state_cb(void)
}
/**
* DIMCB_IoRead - callback from HAL to read an I/O register
* @ptr32: register address
*/
-u32 DIMCB_IoRead(u32 *ptr32)
+u32 dimcb_io_read(u32 *ptr32)
{
return __raw_readl(ptr32);
}
@@ -135,10 +135,10 @@ bool dim2_sysfs_get_state_cb(void)
}
/**
- * DIMCB_IoRead - callback from HAL to read an I/O register
+ * dimcb_io_read - callback from HAL to read an I/O register
* @ptr32: register address
*/